@@ -194,8 +194,7 @@ static void _alarmd_action_exec_do_action(AlarmdActionDialog *action)
 	ENTER_FUNC;
 	
 	if (priv->path) {
-		g_shell_parse_argv(priv->path, &argc, &argv, NULL);
-		if (argv != NULL) {
+		if (g_shell_parse_argv(priv->path, &argc, &argv, NULL)) {
 			g_debug("Running command %s", priv->path);
 			g_spawn_async(g_get_home_dir(),
 					argv,
