@@ -636,12 +636,15 @@ static void _alarmd_queue_event_changed(AlarmdQueue *queue, AlarmdEvent *event)
 
 	priv->events = g_slist_insert_sorted(priv->events, event, _alarmd_event_compare_func);
 
-	if (priv->queued == NULL) {
+        if (priv->queued == NULL || priv->queued_powerup == NULL) { 
 		_alarmd_queue_event_dequeued(queue, NULL);
-	} else if (priv->queued != ALARMD_EVENT(priv->events->data)) {
-		alarmd_event_dequeue(priv->queued);
+        } if (priv->queued != _alarmd_queue_find_first_event(priv->events, FALSE)) { 
+		alarmd_event_dequeue(priv->queued); 
 	}
-
+	if (priv->queued_powerup != _alarmd_queue_find_first_event(priv->events, TRUE)) {
+                alarmd_event_dequeue(priv->queued_powerup);
+       	}
+		
 	alarmd_object_changed(ALARMD_OBJECT(queue));
 
 	LEAVE_FUNC;
